@@ -39,16 +39,9 @@ class Translate(Function):
               'enum': ['ignore', 'points', 'meshes']}
     )
 
-    config_path = Inputs.file(
-        description='File path to the config json file which can be used to mount'
-        'simulation data on HBJSON.',
-        path='data/config.json',
-        optional=True
-    )
-
     data = Inputs.folder(
-        description='Input data that works with config file.',
-        path='data', optional=True
+        description='Input data folder. This folder must include a config.json file',
+        path='input_data', optional=True
     )
 
     @command
@@ -56,7 +49,7 @@ class Translate(Function):
         return 'honeybee-vtk translate --name {{self.name}} --file-type' \
             ' {{self.file_type}} --display-mode {{self.display_mode}}' \
             ' --grid-options {{self.grid_options}}' \
-            ' --config data/config.json input.hbjson --folder target_folder'
+            ' --config input_data/config.json input.hbjson --folder target_folder'
 
     output_file = Outputs.file(
         description='Created file.',
